@@ -10,8 +10,12 @@ def main(args, parser, extra, subparser):
     cli = get_client(
         quiet=args.quiet,
         settings_file=args.settings_file,
-        module=args.module,
+        module_sys=args.module_sys,
         container_tech=args.container_tech,
     )
+
+    # Update config settings on the fly
+    cli.settings.update_params(args.config_params)
+
     # If we don't have a module name, we derive from container URI
     cli.add(args.container_uri, args.module_id)
