@@ -35,10 +35,7 @@ def main(args, parser, extra, subparser):
         return cli.settings.edit()
 
     if command in ["set", "add", "remove"]:
-
-        # Update each param
-        for param in args.params:
-            cli.settings.update_param(command, param)
+        cli.settings.update_param(command, args.params)
 
         # Save settings
         cli.settings.save()
@@ -47,7 +44,7 @@ def main(args, parser, extra, subparser):
     elif command == "get":
         for key in args.params:
             value = cli.settings.get(key)
-            value = value or "is unset"
+            value = "is unset" if value is None else value
             logger.info("%s %s" % (key.ljust(30), value))
 
     else:
